<?php

/**
 * Integration. Order.
 *
 * @package WPDesk\Library\WPCoupons
 */
namespace FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Order;

use WC_Order_Item_Coupon;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\Helper;
use FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\PostMeta;
use FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable;
use WC_Coupon;
use WC_Order;
/**
 * Fire action after make order.
 *
 * @package WPDesk\Library\WPCoupons\Integration
 */
class MakeOrder implements \FlexibleCouponsVendor\WPDesk\PluginBuilder\Plugin\Hookable
{
    /**
     * @var PostMeta
     */
    private $postmeta;
    /**
     * @param PostMeta $postmeta
     */
    public function __construct(\FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\PostMeta $postmeta)
    {
        $this->postmeta = $postmeta;
    }
    /**
     * Fires hooks.
     */
    public function hooks()
    {
        \add_action('woocommerce_checkout_order_processed', [$this, 'order_processed'], 10, 3);
        \add_action('woocommerce_order_item_meta_end', [$this, 'display_coupons_links'], 8, 3);
    }
    public function display_coupons_links($item_id, $item, $order)
    {
        $coupon_key = '_fcpdf_order_item_' . $item_id . '_coupon_id';
        $coupon_id = (int) $order->get_meta($coupon_key, \true);
        $coupon_data = \get_post_meta($coupon_id, '_fcpdf_coupon_data', \true);
        if (!empty($coupon_data) && $item) {
            $coupon = new \WC_Coupon($coupon_id);
            $coupon_code = $coupon->get_id() ? $coupon->get_code() : '';
            $download_url = $coupon->get_id() ? \FlexibleCouponsVendor\WPDesk\Library\WPCoupons\Integration\Helper::make_coupon_url($coupon_data) : '';
            if ($download_url && $coupon_code) {
                echo '<p><a href="' . $download_url . '"><strong>' . \esc_html__('Download PDF coupon', 'flexible-coupons') . '</strong></a></p>';
            }
        }
    }
    /**
     * @param int      $order_id
     * @param array    $posted_data
     * @param WC_Order $order
     */
    public function order_processed(int $order_id, array $posted_data, \WC_Order $order)
    {
        $coupon_items = $order->get_items('coupon');
        foreach ($coupon_items as $coupon_item) {
            if ($coupon_item instanceof \WC_Order_Item_Coupon) {
                $total = (float) $coupon_item->get_discount() + (float) $coupon_item->get_discount_tax();
                $coupon_post_object = \get_page_by_title($coupon_item->get_code(), OBJECT, 'shop_coupon');
                $coupon_id = $coupon_post_object->ID;
                $coupon_data = $this->postmeta->get_private($coupon_id, 'fcpdf_coupon_data');
                if (!empty($coupon_data)) {
                    $coupon_object = new \WC_Coupon($coupon_id);
                    $usage_limit = $coupon_object->get_usage_limit();
                    if (!$usage_limit) {
                        $amount = $coupon_object->get_amount();
                        if ($total > $amount) {
                            $amount = 0;
                        } else {
                            $amount -= $total;
                        }
                        $coupon_object->set_amount(\number_format($amount, 2));
                        $coupon_object->save();
                    }
                }
            }
        }
    }
}
